import { defineComponent, toRefs, reactive, onMounted, ref } from 'vue'
import classes from './index.module.less'
import { ElButton, ElOption, ElSelect } from 'element-plus'
import printIcon from './images/printIcon.png'
import banner from './images/banner.png'
import colVideo from '@/components/col-video/index'
import iconClose from '@/views/login/images/icon_close.png'
import start from '@/components/albumItem/images/start.png'
import teacher from '@/views/videoDetailList/images/teacher.png'
import teacherHeader from '@/common/images/icon_teacher.png'
import musiceIcon from '@/views/videoDetailList/images/musiceIcon.png'
import tagItem from '@/components/tagItem'
import code from './images/code.png'
import musicItem from './modals/musicItem'
import request from '@/helpers/request'
import { useRoute } from 'vue-router'
import { getUserType } from '@/helpers/utils'
import printJS from 'print-js'
export default defineComponent({
  name: 'muiscDetial',
  props: {
    title: {
      type: String,
      default: ''
    }
  },
  components: {
    colVideo,
    tagItem,
    musicItem
  },
  setup(props, conent) {
    const route = useRoute()
    const state = reactive({
      title: props.title,
      id: route.query.id,
      subjectId: '',
      subjectList: [],
      tagList: [],
      teacherDetail: {} as any,
      musicDetail: {} as any,
      musicList: [],
      mp3Type: '',
      activeRow: {} as any,
      showCode: false,
      userType: ''
    })
    const print = ref()
    const getMusicList = async () => {
      try {
        const res = await request.get(
          `/api-website/open/music/sheet/detail/${state.id}`,
          {}
        )

        state.musicDetail = res.data
        state.musicList = res.data.teacher.musicSheetList
        state.subjectList = res.data.background
        state.mp3Type = res.data.audioType
        state.activeRow = res.data.background[0]
        state.subjectId = res.data.background[0].id
        state.teacherDetail = res.data.teacher
      } catch (e) {
        console.log(e)
      }
    }
    const followVideo = async () => {
      try {
        const res = await request.get('/api-website/student/starOrUnStar', {
          params: {
            userId: state.teacherDetail.userId,
            starStatus: state.teacherDetail.star ? 0 : 1
          }
        })
        getMusicList()
        // state.otherVideoList = res.data
      } catch (e) {
        console.log(e)
      }
    }
    const getDetail = (val: string | number) => {
      state.id = val as string
      getMusicList()
    }
    onMounted(() => {
      state.userType = getUserType()
      state.showCode = state.userType == 'STUDENT' ? true : false
      getMusicList()
    })
    const printHander = () => {
      printJS({
        printable: 'containerPrint', // 元素id,不支持多个
        type: 'html',
        targetStyle: ['* '],
        targetStyles: ['*'],
        maxWidth: '', // 最大宽度，默认800,仅支持数字
        style:
          '@page{size:auto; margin: 0;}' +
          '@media print { @page {size: landscape } }' // landscape  默认横向打印
      } as any)
    }
    return () => (
      <>
        <div class={classes.wall}></div>
        <div class={[classes.width1200, classes.musicWrap]}>
          <div class={classes.left}>
            <div class={classes.title}>
              <div class={classes.titleLeft}>
                <p>声部：</p>
                <ElSelect
                  class="w-full subjectChiose"
                  v-model={state.subjectId}
                  placeholder="请选择声部"
                >
                  {state.subjectList.map((item: any) => (
                    <ElOption
                      key={item.id}
                      value={item.id}
                      label={item.track}
                    />
                  ))}
                </ElSelect>
              </div>
              <div class={classes.titleRight}  onClick={() => printHander()}>
                <img src={printIcon} alt="" />
                <p>打印乐谱</p>
              </div>
            </div>
            <div class={classes.musicContent} id='containerPrint' ref="print">
              123
            </div>
            {state.showCode ? (
              <div class={classes.showCode}>
                <div class={classes.showCodeWrap}>
                  <img
                    class={classes.close}
                    src={iconClose}
                    alt=""
                    onClick={() => {
                      state.showCode = false
                    }}
                  />
                  <img class={classes.code} src={code} alt="" />
                  <h2 class={classes.title}>酷乐秀</h2>
                  <p class={classes.conent}>扫码下载酷乐秀APP</p>
                  <p class={classes.subConent}>
                    使用小酷Ai即可智能练习本首曲目哦！
                  </p>
                  <img src={banner} alt="" />
                </div>
              </div>
            ) : null}

            {state.mp3Type == 'MP3' ? (
              <colVideo
                src={state.activeRow.audioFileUrl}
                styleValue={{
                  height: '68px',
                  bacground: '#333'
                }}
                type={'audto'}
                settings={['captions', 'quality', 'speed', 'loop']}
                class={classes.audios}
              ></colVideo>
            ) : null}
          </div>
          <div class={classes.right}>
            <div class={classes.musicInfo}>
              <h2>曲目：{state.musicDetail.musicSheetName}</h2>
              <div class={classes.collect}>
                <img src={start} class={classes.start} alt="" />
                <p>{state.musicDetail.favoriteNum}人收藏</p>
              </div>
              <div class={classes.tagList}>
                {state.tagList.map((item: any) => {
                  return <tagItem title={item.key}>{item.key}</tagItem>
                })}
              </div>
              <p class={classes.subTitle}>
                作曲人：<span>{state.musicDetail.composer}</span>
              </p>
              <p class={classes.subTitle}>
                声部：<span>{state.musicDetail.subjectNames}</span>
              </p>
            </div>
            <div class={classes.btooom}>
              {state.teacherDetail.userId ? (
                <div class={classes.teacherInfo}>
                  <div class={classes.teacherHeadWrap}>
                    <div class={classes.teacherHeadLeft}>
                      <img
                        src={
                          state.teacherDetail.avatar
                            ? state.teacherDetail.avatar
                            : teacherHeader
                        }
                        alt=""
                        class={classes.teacherHeader}
                      />
                      <div class={classes.teacherHeadInfo}>
                        <div class={classes.teacherHeadName}>
                          <span>{state.teacherDetail.userName}</span>
                          {!state.teacherDetail.entryFlag ? (
                            ''
                          ) : (
                            <img
                              src={teacher}
                              class={classes.teacherIcon}
                              alt=""
                            />
                          )}
                          {!state.teacherDetail.musicianFlag ? (
                            ''
                          ) : (
                            <img
                              src={musiceIcon}
                              class={classes.teacherIcon}
                              alt=""
                            />
                          )}
                        </div>
                        <p class={classes.fens}>
                          粉丝 <span>{state.teacherDetail.fansNum}</span>
                        </p>
                      </div>
                    </div>
                    {state.userType == 'STUDENT' ? (
                      <div
                        class={[
                          classes.teacherHeadRight,
                          state.teacherDetail.star ? classes.isStart : ''
                        ]}
                        onClick={() => followVideo()}
                      >
                        {state.teacherDetail.star ? '已关注' : '关注'}
                      </div>
                    ) : null}
                  </div>
                </div>
              ) : null}

              <div class={classes.otherMusic}>
                <h2>Ta的曲谱</h2>
                <div class={classes.otherMusicList}>
                  {state.musicList.map(item => {
                    return (
                      <musicItem
                        item={item}
                        onMusicDetail={val => getDetail(val)}
                      ></musicItem>
                    )
                  })}
                </div>
              </div>
            </div>
          </div>
        </div>
      </>
    )
  }
})
