// import { PaperClipIcon } from '@heroicons/vue/solid'
import { defineComponent, toRefs, reactive, onMounted, ref } from 'vue'
import arrow from '@/components/musicLIstItem/images/arrow.png'
import styles from '../index.module.less'
import albumItem from '@/components/albumItem'
import videoDetailItem from '@/components/videoDetailItem'
import musicLIstItem from '@/components/musicLIstItem'
import hotSearch from '@/components/hotSearch'
import request from '@/helpers/request'
import silder from '@/components/silder'
import searchInput from '@/components/searchInput'
import 'swiper/css'
import 'swiper/css/navigation'
import 'swiper/css/pagination'
import 'swiper/css/scrollbar'
import { ElTabPane, ElTabs } from 'element-plus'
import pagination from '@/components/pagination'
export default defineComponent({
  name: 'searchdetail',
  components: {
    hotSearch,
    silder,
    searchInput,
    albumItem,
    pagination
  },
  setup() {
    const state = reactive({
      albumList: [],
      musicList: [],
      search: {},
      pageInfo: {
        // 分页规则
        limit: 5, // 限制显示条数
        page: 1, // 当前页
        total: 0, // 总条数
        page_size: [10, 20, 40, 50] // 选择限制显示条数
      }
    })

    const getAlbumList = async () => {
      try {
        const res = await request.post('/api-website/open/music/album/list', {
          data: {
            albumStatus: 1,
            ...state.search,
            page: state.pageInfo.page,
            rows: state.pageInfo.limit
          }
        })

        state.albumList = res.data.rows
        state.pageInfo.total = res.data.total
      } catch (e) {
        console.log(e)
      }
    }
    const getList = (val: any) => {
      state.search = { ...val }
      state.pageInfo.page = 1
      getAlbumList()
    }
    onMounted(() => {
      getAlbumList()
      // getMusicList()
    })
    return {
      ...toRefs(state),
      getList,
      getAlbumList
    }
  },
  render() {
    return (
      <div>
        <div>
          <div class={styles.w1200}>
            <div class={styles.section}>
              <div class={styles.albumList}>
                {this.albumList.map(item => {
                  return <albumItem detail={item}></albumItem>
                })}
              </div>
            </div>
          </div>
        </div>
        <pagination
          total={this.pageInfo.total}
          v-model:page={this.pageInfo.page}
          limit={this.pageInfo.limit}
          pageSizes={this.pageInfo.page_size}
          pagination={this.getAlbumList}
        />
      </div>
    )
  }
})
